==> estateplat-common-1.2.4-20201106.073155-493-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttZhjbxxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttZhjbxx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttZhjbxxBdc extends KttZhjbxx {
    private String dfxmxzdm;
    private String dfxmxzmc;
    private String dfdbdm;
    private String dfdbmc;
    private String dfyhlxadm;
    private String dfyhlxamc;
    private String dfyhlxbdm;
    private String dfyhlxbmc;
    private String dfhdytdm;
    private String dfhdytmc;
    @XmlAttribute(
            name = "DFXMXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxmxzdm() {
        return dfxmxzdm;
    }

    public void setDfxmxzdm(String dfxmxzdm) {
        this.dfxmxzdm = dfxmxzdm;
    }
    @XmlTransient
    public String getDfxmxzmc() {
        return dfxmxzmc;
    }

    public void setDfxmxzmc(String dfxmxzmc) {
        this.dfxmxzmc = dfxmxzmc;
    }
    @XmlAttribute(
            name = "DFDBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdbdm() {
        return dfdbdm;
    }

    public void setDfdbdm(String dfdbdm) {
        this.dfdbdm = dfdbdm;
    }
    @XmlTransient
    public String getDfdbmc() {
        return dfdbmc;
    }

    public void setDfdbmc(String dfdbmc) {
        this.dfdbmc = dfdbmc;
    }
    @XmlAttribute(
            name = "DFYHLXADM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxadm() {
        return dfyhlxadm;
    }

    public void setDfyhlxadm(String dfyhlxadm) {
        this.dfyhlxadm = dfyhlxadm;
    }
    @XmlTransient
    public String getDfyhlxamc() {
        return dfyhlxamc;
    }

    public void setDfyhlxamc(String dfyhlxamc) {
        this.dfyhlxamc = dfyhlxamc;
    }
    @XmlAttribute(
            name = "DFYHLXBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxbdm() {
        return dfyhlxbdm;
    }

    public void setDfyhlxbdm(String dfyhlxbdm) {
        this.dfyhlxbdm = dfyhlxbdm;
    }
    @XmlTransient
    public String getDfyhlxbmc() {
        return dfyhlxbmc;
    }

    public void setDfyhlxbmc(String dfyhlxbmc) {
        this.dfyhlxbmc = dfyhlxbmc;
    }
    @XmlAttribute(
            name = "DFHDYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhdytdm() {
        return dfhdytdm;
    }

    public void setDfhdytdm(String dfhdytdm) {
        this.dfhdytdm = dfhdytdm;
    }
    @XmlTransient
    public String getDfhdytmc() {
        return dfhdytmc;
    }

    public void setDfhdytmc(String dfhdytmc) {
        this.dfhdytmc = dfhdytmc;
    }
}

==> estateplat-common-1.2.4-20201112.062706-499-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttZhjbxxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttZhjbxx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttZhjbxxBdc extends KttZhjbxx {
    private String dfxmxzdm;
    private String dfxmxzmc;
    private String dfdbdm;
    private String dfdbmc;
    private String dfyhlxadm;
    private String dfyhlxamc;
    private String dfyhlxbdm;
    private String dfyhlxbmc;
    private String dfhdytdm;
    private String dfhdytmc;
    @XmlAttribute(
            name = "DFXMXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxmxzdm() {
        return dfxmxzdm;
    }

    public void setDfxmxzdm(String dfxmxzdm) {
        this.dfxmxzdm = dfxmxzdm;
    }
    @XmlAttribute(
            name = "DFXMXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxmxzmc() {
        return dfxmxzmc;
    }

    public void setDfxmxzmc(String dfxmxzmc) {
        this.dfxmxzmc = dfxmxzmc;
    }
    @XmlAttribute(
            name = "DFDBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdbdm() {
        return dfdbdm;
    }

    public void setDfdbdm(String dfdbdm) {
        this.dfdbdm = dfdbdm;
    }
    @XmlAttribute(
            name = "DFDBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdbmc() {
        return dfdbmc;
    }

    public void setDfdbmc(String dfdbmc) {
        this.dfdbmc = dfdbmc;
    }
    @XmlAttribute(
            name = "DFYHLXADM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxadm() {
        return dfyhlxadm;
    }

    public void setDfyhlxadm(String dfyhlxadm) {
        this.dfyhlxadm = dfyhlxadm;
    }
    @XmlAttribute(
            name = "DFYHLXAMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxamc() {
        return dfyhlxamc;
    }

    public void setDfyhlxamc(String dfyhlxamc) {
        this.dfyhlxamc = dfyhlxamc;
    }
    @XmlAttribute(
            name = "DFYHLXBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxbdm() {
        return dfyhlxbdm;
    }

    public void setDfyhlxbdm(String dfyhlxbdm) {
        this.dfyhlxbdm = dfyhlxbdm;
    }
    @XmlAttribute(
            name = "DFYHLXBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxbmc() {
        return dfyhlxbmc;
    }

    public void setDfyhlxbmc(String dfyhlxbmc) {
        this.dfyhlxbmc = dfyhlxbmc;
    }
    @XmlAttribute(
            name = "DFHDYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhdytdm() {
        return dfhdytdm;
    }

    public void setDfhdytdm(String dfhdytdm) {
        this.dfhdytdm = dfhdytdm;
    }
    @XmlAttribute(
            name = "DFHDYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhdytmc() {
        return dfhdytmc;
    }

    public void setDfhdytmc(String dfhdytmc) {
        this.dfhdytmc = dfhdytmc;
    }
}
